# IBM Generative AI Python SDK


This is the Python SDK for IBM Foundation Models Studio to bring IBM Generative AI (GenAI) into Python programs and to also extend it with useful operations and types.

:books:	**API Documentation: [Link](https://ibm.github.io/ibm-generative-ai/)**

*This is an early access library and requires invitation to use the technical preview of [watsonx.ai](https://watsonx.ai/). You can join the waitlist by visiting. https://www.ibm.com/products/watsonx-ai.*

*Looking for the JavaScript/TypeScript version? Check out https://github.com/IBM/ibm-generative-ai-node-sdk.*

[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://github.com/IBM/ibm-generative-ai/blob/main/LICENSE)
![PyPI](https://img.shields.io/pypi/v/ibm-generative-ai)
[![Build & Test](https://github.com/IBM/ibm-generative-ai/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/IBM/ibm-generative-ai/actions/workflows/main.yml)
[![Integration Tests](https://github.com/IBM/ibm-generative-ai/actions/workflows/integration-test.yml/badge.svg)](https://github.com/IBM/ibm-generative-ai/actions/workflows/integration-test.yml)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ibm-generative-ai)
[![Coverage Status](https://coveralls.io/repos/github/IBM/ibm-generative-ai/badge.svg?branch=main)](https://coveralls.io/github/IBM/ibm-generative-ai?branch=main)

## Important Information for Starters and Contributors
- Do you want to get started with GenAI? check the [Getting Started Guideline](GETTING_STARTED.md) to install and develop amazing AI applications with IBM Generative AI SDK.
- Do you want to contribute to the project? IBM Generative AI is an open-source project that welcomes the community to contribute with documentation, tests, bug corrections, and new fuctionality in the form of [extensions](EXTENSIONS.md). Please read our [code of counduct](CODE_OF_CONDUCT.md) to learn the expected behavior from participants that contribute to the project, and our [contribution guide](CONTRIBUTING.md) to learn the gitflow and steps to submit pull requests.
- Looking for the GenAI team contact information? click [here](STARTER_TEAM.md)

<!-- vscode-markdown-toc-config
	numbering=false
	autoSave=true
	/vscode-markdown-toc-config -->
<!-- /vscode-markdown-toc -->
